# blueprints
Blueprints is a pythonic library that constructs Mujoco simulations and gives access to runtime data. It is designed to simplify access to mujoco and provide helpful subroutines for procedural generation, aiding environment randomization, curriculum learning, hindsight experiance replay and other RL paradigms aiming to manipulate the environment.

## Installation
Directly from PyPI:
```
$ pip install mujoco_blueprints
```

Alternatively from github:
```
git clone https://github.com/mortimervonchappuis/mujoco_blueprints.git
```